import value from "dll/module";

it("should have the correct default export", function() {
	expect(value).toBe("ok");
});
